@@ -97,24 +97,24 @@ apply_nest_asyncio()
 def _get_rdkit_mol_from_uuid(calculation_uuid: str) -> RdkitMol:
     stjames_mol_dict = rowan.retrieve_calculation_molecules(calculation_uuid)[-1]
 
-    return Chem.MolFromXYZBlock(stjames.Molecule(**stjames_mol_dict).to_xyz())  # type: ignore [attr-defined]
+    return Chem.MolFromXYZBlock(stjames.Molecule(**stjames_mol_dict).to_xyz())
 
 
 def _embed_rdkit_mol(rdkm: RdkitMol) -> RdkitMol:
     try:
-        AllChem.SanitizeMol(rdkm)
+        AllChem.SanitizeMol(rdkm)  # type: ignore [attr-defined]
     except Exception as e:
         raise ValueError("Molecule could not be generated -- invalid chemistry!") from e
 
-    rdkm = AllChem.AddHs(rdkm)
+    rdkm = AllChem.AddHs(rdkm)  # type: ignore [attr-defined]
     try:
-        assert AllChem.EmbedMolecule(rdkm, maxAttempts=200) >= 0
+        assert AllChem.EmbedMolecule(rdkm, maxAttempts=200) >= 0  # type: ignore [attr-defined]
     except AssertionError as e:
-        status1 = AllChem.EmbedMolecule(rdkm, maxAttempts=200, useRandomCoords=True)
+        status1 = AllChem.EmbedMolecule(rdkm, maxAttempts=200, useRandomCoords=True)  # type: ignore [attr-defined]
         if status1 < 0:
             raise ValueError("Cannot embed molecule!") from e
     try:
-        assert AllChem.MMFFOptimizeMolecule(rdkm, maxIters=200) >= 0  # type: ignore    [call-arg]
+        assert AllChem.MMFFOptimizeMolecule(rdkm, maxIters=200) >= 0  # type: ignore [attr-defined]
     except AssertionError:
         pass
 
@@ -477,9 +477,9 @@ async def _single_energy(
     get_api_key()
     method = stjames.Method(method)
 
-    if mol.GetNumConformers() == 0:  # type: ignore    [call-arg]
+    if mol.GetNumConformers() == 0:
         mol = _embed_rdkit_mol(mol)
-        if mol.GetNumConformers() == 0:  # type: ignore    [call-arg]
+        if mol.GetNumConformers() == 0:
             raise NoConformersError("This molecule has no conformers")
 
     if method not in FAST_METHODS:
@@ -489,7 +489,7 @@ async def _single_energy(
 
     workflow_uuids = []
     for conformer in mol.GetConformers():
-        cid = conformer.GetId()  # type: ignore    [call-arg]
+        cid = conformer.GetId()
         stjames_mol = _rdkit_to_stjames(mol, cid)
         post = rowan.submit_workflow(
             name=name,
@@ -623,9 +623,9 @@ async def _single_optimize(
     get_api_key()
     method = stjames.Method(method)
 
-    if mol.GetNumConformers() == 0:  # type: ignore    [call-arg]
+    if mol.GetNumConformers() == 0:
         mol = _embed_rdkit_mol(mol)
-        if mol.GetNumConformers() == 0:  # type: ignore    [call-arg]
+        if mol.GetNumConformers() == 0:
             raise NoConformersError("This molecule has no conformers")
 
     if method not in FAST_METHODS:
@@ -637,7 +637,7 @@ async def _single_optimize(
 
     workflow_uuids = []
     for conformer in mol.GetConformers():
-        cid = conformer.GetId()  # type: ignore    [call-arg]
+        cid = conformer.GetId()
         stjames_mol = _rdkit_to_stjames(mol, cid)
 
         post = rowan.submit_workflow(
@@ -677,7 +677,7 @@ async def _single_optimize(
     energies = [cacluation[-1]["energy"] for cacluation in calculations]
 
     for i, conformer in enumerate(optimized_mol.GetConformers()):
-        conformer.SetPositions(np.array(optimized_positions[i]))  # type: ignore  [attr-defined]
+        conformer.SetPositions(np.array(optimized_positions[i]))
 
     return {
         "molecule": mol,
@@ -796,9 +796,9 @@ async def _single_conformers(
     get_api_key()
     method = stjames.Method(method)
 
-    if mol.GetNumConformers() == 0:  # type: ignore    [call-arg]
+    if mol.GetNumConformers() == 0:
         mol = _embed_rdkit_mol(mol)
-        if mol.GetNumConformers() == 0:  # type: ignore    [call-arg]
+        if mol.GetNumConformers() == 0:
             raise NoConformersError("This molecule has no conformers")
 
     if method not in FAST_METHODS:
@@ -844,7 +844,7 @@ async def _single_conformers(
         raise NoConformersError("This molecule has no conformers")
 
     sorted_data = sorted(
-        zip(data["energies"], data["conformer_uuids"]),
+        zip(data["energies"], data["conformer_uuids"], strict=True),
         key=lambda x: x[0],
     )
 
@@ -858,12 +858,12 @@ async def _single_conformers(
     lowest_n_uuids = [item[1][0] for item in sorted_data[:num_conformers]]
     lowest_energies = [item[0] for item in sorted_data[:num_conformers]]
 
-    AllChem.EmbedMultipleConfs(mol, numConfs=num_conformers)
+    AllChem.EmbedMultipleConfs(mol, numConfs=num_conformers)  # type: ignore [attr-defined]
 
     for i, conformer in enumerate(mol.GetConformers()):
         atoms = rowan.retrieve_calculation_molecules(lowest_n_uuids[i])[-1]["atoms"]
         pos = [atom["position"] for atom in atoms]
-        conformer.SetPositions(np.array(pos))  # type: ignore  [attr-defined]
+        conformer.SetPositions(np.array(pos))
 
     return {
         "molecule": mol,
@@ -959,9 +959,9 @@ async def _single_charges(
     get_api_key()
     method = stjames.Method(method)
 
-    if mol.GetNumConformers() == 0:  # type: ignore    [call-arg]
+    if mol.GetNumConformers() == 0:
         mol = _embed_rdkit_mol(mol)
-        if mol.GetNumConformers() == 0:  # type: ignore    [call-arg]
+        if mol.GetNumConformers() == 0:
             raise NoConformersError("This molecule has no conformers")
 
     if method not in FAST_METHODS:
@@ -971,7 +971,7 @@ async def _single_charges(
 
     workflow_uuids = []
     for conformer in mol.GetConformers():
-        cid = conformer.GetId()  # type: ignore    [call-arg]
+        cid = conformer.GetId()
 
         post = rowan.submit_workflow(
             name=name,
